@@ -192,18 +192,18 @@ def reset_dir(filepath):
             os.remove(filepath + os.sep + each_file)
 
 
-def label_create_split(args):
+def label_create_split(args, data_dir):
     """
     valid_data would be splited from original, not include the augment data.
     """
 
     def create_label(lines, label_type='train'):
-        with open(args["basic"]["top_dir"] + os.sep + 'ImageSets/Main/%s.txt' % label_type, 'w', encoding='utf8') as f:
+        with open(data_dir + os.sep + 'ImageSets/Main/%s.txt' % label_type, 'w', encoding='utf8') as f:
             f.writelines(lines)
 
-    os.makedirs(args["basic"]["top_dir"] + os.sep + 'ImageSets/Main', exist_ok=True)
+    os.makedirs(data_dir + os.sep + 'ImageSets/Main', exist_ok=True)
     lines = []
-    for labelfile in os.listdir(args["basic"]["top_dir"] + os.sep + 'Annotations'):
+    for labelfile in os.listdir(data_dir + os.sep + 'Annotations'):
         filename = os.path.splitext(labelfile)[0]
         lines.append(filename + "\n")
     orilines = [i for i in lines if not i.startswith('imgaug_')]
@@ -217,15 +217,14 @@ def label_create_split(args):
     print('data split complete')
 
 
-def data_aug(aug_file):
+def data_aug(aug_file, data_dir):
     config_dict, methods = get_methods_from_yml(aug_file)
-    top_dir = config_dict["basic"]["top_dir"]
 
     t1 = time.time()
-    if not os.path.exists(top_dir):
+    if not os.path.exists(data_dir):
         raise FileNotFoundError('未能找到相应文件夹，请核查传入的路径')
-    IMG_DIR = top_dir + os.sep + "JPEGImages"
-    XML_DIR = top_dir + os.sep + "Annotations"
+    IMG_DIR = data_dir + os.sep + "JPEGImages"
+    XML_DIR = data_dir + os.sep + "Annotations"
     reset_dir(IMG_DIR)
     reset_dir(XML_DIR)
 
@@ -235,10 +234,10 @@ def data_aug(aug_file):
     else:
         threading_treat(config_dict, XML_DIR, IMG_DIR, imgfiles, methods)
     if config_dict["basic"]["split"]:
-        label_create_split(config_dict)
+        label_create_split(config_dict, data_dir)
 
     # 生成新的trainval.txt
-    voc_txt_dir = os.path.join(top_dir, "ImageSets", "Main")
+    voc_txt_dir = os.path.join(data_dir, "ImageSets", "Main")
     if os.path.exists(voc_txt_dir):
         for voc_txt in os.listdir(voc_txt_dir):
             rm_path = os.path.join(voc_txt_dir, voc_txt)
@@ -267,4 +266,5 @@ if __name__ == "__main__":
     # aug(args)
 
     aug_config = "./aug.yml"
-    data_aug(aug_config)
+    data_folder = "../../test/voc_eva_clothes_helmet"
+    data_aug(aug_config, data_folder)
