@@ -22,7 +22,7 @@ class CheckCOCO(CheckDataset):
 
     def __init__(self, dataset_dir, labels=None, output_dir=None):
         super().__init__(dataset_dir, labels, output_dir)
-        self.img_dir = os.path.join(dataset_dir, "Images", "train")
+        self.img_dir = os.path.join(dataset_dir, "train")
 
     # 判断标注数据(.json)是否存在错误
     def is_anno_break(self):
